@@ -1,5 +1,6 @@
 /*
- * Copyright 2001-2011 Vedder Bruno.
+ * Copyright holder 2001-2011 Vedder Bruno.
+ * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
  *	
  * This file is part of Osmose, a Sega Master System/Game Gear software 
  * emulator.
@@ -63,7 +64,7 @@ QOsmoseConfiguration::~QOsmoseConfiguration()
  *
  * This slot is called when the tool button is clicked. It then open a file
  * selection dialog to get an existing directory to store Battery Backed RAM.
- * The corresponding QLineEdit is also updated with the choosen path.
+ * The corresponding QLineEdit is also updated with the chosen path.
  */
 void QOsmoseConfiguration::selectBBRPath()
 {
@@ -82,7 +83,7 @@ void QOsmoseConfiguration::selectBBRPath()
  *
  * This slot is called when the tool button is clicked. It then open a file
  * selection dialog to get an existing directory to store screenshots.
- * The corresponding QLineEdit is also updated with the choosen path.
+ * The corresponding QLineEdit is also updated with the chosen path.
  */
 void QOsmoseConfiguration::selectScreenshotPath()
 {
@@ -101,7 +102,7 @@ void QOsmoseConfiguration::selectScreenshotPath()
  *
  * This slot is called when the tool button is clicked. It then open a file
  * selection dialog to get an existing directory to store save states.
- * The corresponding QLineEdit is also updated with the choosen path.
+ * The corresponding QLineEdit is also updated with the chosen path.
  */
 void QOsmoseConfiguration::selectSaveStatePath()
 {
@@ -120,7 +121,7 @@ void QOsmoseConfiguration::selectSaveStatePath()
  *
  * This slot is called when the tool button is clicked. It then open a file
  * selection dialog to get an existing directory to store ripped tiles.
- * The corresponding QLineEdit is also updated with the choosen path.
+ * The corresponding QLineEdit is also updated with the chosen path.
  */
 void QOsmoseConfiguration::selectTileRipPath()	
 {
@@ -139,7 +140,7 @@ void QOsmoseConfiguration::selectTileRipPath()
  *
  * This slot is called when the tool button is clicked. It then open a file
  * selection dialog to get an existing directory to store ripped sounds.
- * The corresponding QLineEdit is also updated with the choosen path.
+ * The corresponding QLineEdit is also updated with the chosen path.
  */
 void QOsmoseConfiguration::selectSoundRipPath()
 {
@@ -215,7 +216,7 @@ void QOsmoseConfiguration::completeConnections()
  */
 void QOsmoseConfiguration::synchronizeWithConfiguration()
 {
-	// Synchronize pathes.
+	// Synchronize paths.
 	screenshotsPathLineEdit->setText(ocf->getScreenshotPath().c_str());  
 	bbrPathLineEdit->setText(ocf->getBBRPath().c_str());
 	saveStatePathLineEdit->setText(ocf->getSaveStatePath().c_str());
@@ -689,8 +690,6 @@ void QOsmoseConfiguration::joyButton8Changed(bool pressed)
 /* JoystickListener interface */
 void QOsmoseConfiguration::buttonChanged(unsigned int button, bool pressed)
 {
-	QLabel *label;
-	
 	switch(button)
 	{
 		case 0:
@@ -722,10 +721,12 @@ void QOsmoseConfiguration::buttonChanged(unsigned int button, bool pressed)
 
 void QOsmoseConfiguration::xAxisChanged(int value)
 {
+    Q_UNUSED(value)
 }
 
 void QOsmoseConfiguration::yAxisChanged(int value)
 {
+    Q_UNUSED(value)
 }
 
 void QOsmoseConfiguration::joystickError()
