@@ -1,5 +1,6 @@
 /*****************************************************************************
- * Copyright 2001-2011 Vedder Bruno.
+ * Copyright holder 2001-2011 Vedder Bruno.
+ * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
  *	
  * This file is part of Osmose, a Sega Master System/Game Gear software 
  * emulator.
@@ -594,7 +595,7 @@ void SmsDebugger::exec_cmd(char *cmd, int param1, int  param2)
 
 void SmsDebugger::unknownCommand()
 {
-    cout << "Unkown command." << endl;
+    cout << "Unknown command." << endl;
 }
 
 void SmsDebugger::setScanlineBreakpoint(int scanline)
