@@ -1,7 +1,8 @@
 /*
- * Copyright 2001-2011 Vedder Bruno.
- *	
- * This file is part of Osmose, a Sega Master System/Game Gear software 
+ * Copyright holder 2001-2011 Vedder Bruno.
+ * Contributor 2016 Carlos Donizete Froes [a.k.a coringao]
+ *
+ * This file is part of Osmose, a Sega Master System/Game Gear software
  * emulator.
  *
  * Osmose is free software: you can redistribute it and/or modify
@@ -17,13 +18,12 @@
  * You should have received a copy of the GNU General Public License
  * along with Osmose.  If not, see <http://www.gnu.org/licenses/>.
  */
- 
+
 #ifndef VERSION_H
 #define VERSION_H
 
-// These for definitions should be coherent !
-#define __OSMOSE_VERSION__ "OsmOse 0.9.96"
-#define MAJOR  0
-#define MIDDLE 9
-#define MINOR  96
+// These four definitions should be coherent!
+#define __OSMOSE_VERSION__ "Osmose Emulator"
+#define MAJOR  1
+#define MIDDLE 0
 #endif
